@@ -40,7 +40,7 @@ def logIt(it, **kwargs):
     #     print(it, **kwargs)
     print(it, **kwargs)
 
-def loadSettings(logsFileName=None, withColors=False) :
+def loadSettings(logsFileName=None, withColors=False, disabledByDefault=LEVEL_NOT_ACTIVE_BY_DEFAULT_LIST) :
     global LOG_HELPER_SETTINGS
     colorama.deinit()
     activeEnvironment = SettingHelper.getActiveEnvironment()
@@ -52,7 +52,7 @@ def loadSettings(logsFileName=None, withColors=False) :
             LOGS_WITH_COLORS: colorsAreEnabled
         },
         **{
-            level: (c.TRUE if level not in LEVEL_NOT_ACTIVE_BY_DEFAULT_LIST and EnvironmentHelper.isTrue(level, default=True) else c.FALSE) for level in LogHelperHelper.LEVEL_DICTIONARY
+            level: (c.TRUE if level not in disabledByDefault and EnvironmentHelper.isTrue(level, default=True) else c.FALSE) for level in LogHelperHelper.LEVEL_DICTIONARY
         }
     }
     if colorsAreEnabled:
